<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * HELPER COMMENT START
 * 
 * This is the main class that is responsible for registering
 * the core functions, including the files and setting up all features. 
 * 
 * To add a new class, here's what you need to do: 
 * 1. Add your new class within the following folder: core/includes/classes
 * 2. Create a new variable you want to assign the class to (as e.g. public $helpers)
 * 3. Assign the class within the instance() function ( as e.g. self::$instance->helpers = new Smart_Ai_Content_Creator_Helpers();)
 * 4. Register the class you added to core/includes/classes within the includes() function
 * 
 * HELPER COMMENT END
 */

if ( ! class_exists( 'Smart_Ai_Content_Creator' ) ) :

	/**
	 * Main Smart_Ai_Content_Creator Class.
	 *
	 * @package		SMAICC
	 * @subpackage	Classes/Smart_Ai_Content_Creator
	 * @since		0.1.1
	 * @author		Web Dimensions, Inc.
	 */
	final class Smart_Ai_Content_Creator {

		/**
		 * The real instance
		 *
		 * @access	private
		 * @since	0.1.1
		 * @var		object|Smart_Ai_Content_Creator
		 */
		private static $instance;

		/**
		 * SMAICC helpers object.
		 *
		 * @access	public
		 * @since	0.1.1
		 * @var		object|Smart_Ai_Content_Creator_Helpers
		 */
		public $helpers;

		/**
		 * SMAICC settings object.
		 *
		 * @access	public
		 * @since	0.1.1
		 * @var		object|Smart_Ai_Content_Creator_Settings
		 */
		public $settings;

		/**
		 * Throw error on object clone.
		 *
		 * Cloning instances of the class is forbidden.
		 *
		 * @access	public
		 * @since	0.1.1
		 * @return	void
		 */
		public function __clone() {
			_doing_it_wrong( __FUNCTION__, __( 'You are not allowed to clone this class.', 'smart-ai-content-creator' ), '0.1.1' );
		}

		/**
		 * Disable unserializing of the class.
		 *
		 * @access	public
		 * @since	0.1.1
		 * @return	void
		 */
		public function __wakeup() {
			_doing_it_wrong( __FUNCTION__, __( 'You are not allowed to unserialize this class.', 'smart-ai-content-creator' ), '0.1.1' );
		}

		/**
		 * Main Smart_Ai_Content_Creator Instance.
		 *
		 * Insures that only one instance of Smart_Ai_Content_Creator exists in memory at any one
		 * time. Also prevents needing to define globals all over the place.
		 *
		 * @access		public
		 * @since		0.1.1
		 * @static
		 * @return		object|Smart_Ai_Content_Creator	The one true Smart_Ai_Content_Creator
		 */
		public static function instance() {
			if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Smart_Ai_Content_Creator ) ) {
				self::$instance					= new Smart_Ai_Content_Creator;
				self::$instance->base_hooks();
				self::$instance->includes();
				self::$instance->helpers		= new Smart_Ai_Content_Creator_Helpers();
				self::$instance->settings		= new Smart_Ai_Content_Creator_Settings();

				//Fire the plugin logic
				new Smart_Ai_Content_Creator_Run();

				/**
				 * Fire a custom action to allow dependencies
				 * after the successful plugin setup
				 */
				do_action( 'SMAICC/plugin_loaded' );
			}

			return self::$instance;
		}

		/**
		 * Include required files.
		 *
		 * @access  private
		 * @since   0.1.1
		 * @return  void
		 */
		private function includes() {
			require_once SMAICC_PLUGIN_DIR . 'core/includes/classes/class-smart-ai-content-creator-helpers.php';
			require_once SMAICC_PLUGIN_DIR . 'core/includes/classes/class-smart-ai-content-creator-settings.php';
      require_once SMAICC_PLUGIN_DIR . 'core/includes/classes/class-smart-ai-content-creator-update-checker.php';
      require_once SMAICC_PLUGIN_DIR . 'core/includes/classes/smart-ai-content-creator-metabox.php';

			if ( defined( 'WP_CLI' ) && WP_CLI ){
				require_once SMAICC_PLUGIN_DIR . 'core/includes/classes/class-smart-ai-content-creator-cli.php';
			}

			require_once SMAICC_PLUGIN_DIR . 'core/includes/classes/class-smart-ai-content-creator-run.php';
		}

		/**
		 * Add base hooks for the core functionality
		 *
		 * @access  private
		 * @since   0.1.1
		 * @return  void
		 */
		private function base_hooks() {
			add_action( 'plugins_loaded', array( self::$instance, 'load_textdomain' ) );
		}

		/**
		 * Loads the plugin language files.
		 *
		 * @access  public
		 * @since   0.1.1
		 * @return  void
		 */
		public function load_textdomain() {
			load_plugin_textdomain( 'smart-ai-content-creator', FALSE, dirname( plugin_basename( SMAICC_PLUGIN_FILE ) ) . '/languages/' );
		}

	}

endif; // End if class_exists check.